@@ -24,6 +24,8 @@ __all__ = (
     "DeploymentUpdateTypeType",
     "EnvironmentAccountConnectionRequesterAccountTypeType",
     "EnvironmentAccountConnectionStatusType",
+    "EnvironmentDeployedWaiterName",
+    "EnvironmentTemplateVersionRegisteredWaiterName",
     "ListEnvironmentAccountConnectionsPaginatorName",
     "ListEnvironmentTemplateVersionsPaginatorName",
     "ListEnvironmentTemplatesPaginatorName",
@@ -34,7 +36,13 @@ __all__ = (
     "ListServicesPaginatorName",
     "ListTagsForResourcePaginatorName",
     "ProvisioningType",
+    "ServiceCreatedWaiterName",
+    "ServiceDeletedWaiterName",
+    "ServiceInstanceDeployedWaiterName",
+    "ServicePipelineDeployedWaiterName",
     "ServiceStatusType",
+    "ServiceTemplateVersionRegisteredWaiterName",
+    "ServiceUpdatedWaiterName",
     "TemplateVersionStatusType",
 )
 
@@ -54,6 +62,8 @@ EnvironmentAccountConnectionRequesterAccountTypeType = Literal[
     "ENVIRONMENT_ACCOUNT", "MANAGEMENT_ACCOUNT"
 ]
 EnvironmentAccountConnectionStatusType = Literal["CONNECTED", "PENDING", "REJECTED"]
+EnvironmentDeployedWaiterName = Literal["environment_deployed"]
+EnvironmentTemplateVersionRegisteredWaiterName = Literal["environment_template_version_registered"]
 ListEnvironmentAccountConnectionsPaginatorName = Literal["list_environment_account_connections"]
 ListEnvironmentTemplateVersionsPaginatorName = Literal["list_environment_template_versions"]
 ListEnvironmentTemplatesPaginatorName = Literal["list_environment_templates"]
@@ -64,6 +74,10 @@ ListServiceTemplatesPaginatorName = Literal["list_service_templates"]
 ListServicesPaginatorName = Literal["list_services"]
 ListTagsForResourcePaginatorName = Literal["list_tags_for_resource"]
 ProvisioningType = Literal["CUSTOMER_MANAGED"]
+ServiceCreatedWaiterName = Literal["service_created"]
+ServiceDeletedWaiterName = Literal["service_deleted"]
+ServiceInstanceDeployedWaiterName = Literal["service_instance_deployed"]
+ServicePipelineDeployedWaiterName = Literal["service_pipeline_deployed"]
 ServiceStatusType = Literal[
     "ACTIVE",
     "CREATE_FAILED",
@@ -80,6 +94,8 @@ ServiceStatusType = Literal[
     "UPDATE_FAILED_CLEANUP_IN_PROGRESS",
     "UPDATE_IN_PROGRESS",
 ]
+ServiceTemplateVersionRegisteredWaiterName = Literal["service_template_version_registered"]
+ServiceUpdatedWaiterName = Literal["service_updated"]
 TemplateVersionStatusType = Literal[
     "DRAFT", "PUBLISHED", "REGISTRATION_FAILED", "REGISTRATION_IN_PROGRESS"
 ]
